package com.usky.backend.controller;
import com.usky.backend.domain.MetricItemVo;
import com.usky.backend.domain.StatusVO;
import com.usky.backend.domain.request.HistoryQueryVo;
import com.usky.backend.domain.request.LastQueryVo;
import com.usky.backend.domain.response.HistoryResultVo;
import com.usky.backend.domain.response.LastResultVo;
import com.usky.backend.service.DataQueryService;
import com.usky.common.core.bean.ApiResult;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.*;

import java.time.LocalDateTime;
import java.util.ArrayList;
import java.util.List;

/**
 * <p>
 *  数据统一查询 前端控制器
 * </p>
 *
 */
@RestController
@Api(tags = "数据统一查询")
@RequestMapping("/dataQuery")
public class DataQueryController {
    @Autowired
    private DataQueryService dataQueryService;

    @GetMapping("/history")
    @ApiOperation("获取单个设备单属性历史数据")
    public ApiResult<HistoryResultVo> history(@RequestParam("startTime") String startTime,
                                              @RequestParam("endTime") String endTime,
                                              @RequestParam("deviceId") String deviceId,
                                              @RequestParam("metric") String metric ) {
        //以下是mock模拟数据
        List<MetricItemVo> items = new ArrayList<>();
        items.add(new MetricItemVo(LocalDateTime.now(),12.3));
        HistoryResultVo historyResultVo = new HistoryResultVo(deviceId,metric,items);
        return ApiResult.success(historyResultVo);
    }

    @PostMapping("/history")
    @ApiOperation("获取单个设备多属性历史数据")
    public ApiResult<List<HistoryResultVo>> history(@RequestBody HistoryQueryVo historyQueryVo) {
        List<HistoryResultVo> result  = new ArrayList<>();
        List<MetricItemVo> items = new ArrayList<>();
        items.add(new MetricItemVo(LocalDateTime.now(),12.3));
        HistoryResultVo historyResultVo = new HistoryResultVo(historyQueryVo.getDeviceId(),"cpu.load",items);
        result.add(historyResultVo);
        return ApiResult.success(result);
    }

    /**
     * 获取单个设备多指标实时数据
     * @param lastQueryVo
     * @return
     */
    @PostMapping("/last")
    @ApiOperation("获取单个设备多指标实时数据")
    public ApiResult<List<LastResultVo>> last(@RequestBody LastQueryVo lastQueryVo) {
        return ApiResult.success(dataQueryService.last(lastQueryVo));
    }

    /**
     * 查询设备状态
     * @return
     */
    @GetMapping("/status")
    public ApiResult<List<StatusVO>> status(){
        return ApiResult.success(dataQueryService.status());
    }

}

